==> hoteldruid-mod-fr_2.3.1-1.tar.gz: fr/modt_pay.php <==
<?php

switch ($messaggio) {

case "Procedere con la prenotazione":	$messaggio = "Proceed booking"; $tr = 1; break;
case "altro":  				$messaggio = "other"; $tr = 1; break;
case "Indirizzo":  			$messaggio = "Address"; $tr = 1; break;
case "Prenota":  			$messaggio = "Book"; $tr = 1; break;
case "comportati come se non vi fosse più disponibilità con questa frase alternativa":	$messaggio = "Show that there is no more availability with this alternative phrase"; $tr = 1; break;
case "Nota: questi dati verranno utilizzati solo in relazione<br> al servizio offerto e comunicati solo a PayPal per il<br> completamento della prenotazione":	$messaggio = "Note: this data will be used only in relation to<br> this service and passed only to PayPal for the<br> completion of the reservation"; $tr = 1; break;
case "Un codice di verifica è stato inviato a":	$messaggio = "A verification code has been sent to"; $tr = 1; break;
case "Controlla la posta e inserisci il codice in questa pagina per effettuare la prenotazione":	$messaggio = "Check your mail and insert the code in this page to make the reservation"; $tr = 1; break;
case "Codice di verifica":  		$messaggio = "Verification code"; $tr = 1; break;
case "Annulla":  			$messaggio = "Cancel"; $tr = 1; break;
case "Per procedere con la prenotazione inserisci il codice o segui questo link":	$messaggio = "To proceed with reservation insert the code or follow this link"; $tr = 1; break;
case "Codice verifica prenotazione":	$messaggio = "Reservation verification code"; $tr = 1; break;
case "Numero eccesivo di richieste inviate dallo stesso computer":	$messaggio = "Excessive number of requests sent from the same computer"; $tr = 1; break;
case "Completa la prenotazione pagando la caparra con PayPal":	$messaggio = "To complete the reservation you have to pay the deposit with PayPal"; $tr = 1; break;
case "Quando il pagamento della caparra sarà completato riceverai una email con la conferma della prenotazione":	$messaggio = "When the deposit payment will be completed you will receive an email confirming the reservation"; $tr = 1; break;
case "Paga la caparra con PayPal":  	$messaggio = "Pay the deposit with PayPal"; $tr = 1; break;
case "Nota: i dati della carta di credito verranno elaborati dai<br> server sicuri di PayPal ed in nessun caso comunicati a questo sito":	$messaggio = "Note: credit card data will be processed by PayPal<br> secure servers and never revealed to this site"; $tr = 1; break;
case "Prenotazione":  			$messaggio = "Reservation"; $tr = 1; break;
case "Errore transazione PayPal":  	$messaggio = "PayPal transaction error"; $tr = 1; break;
case "Errore":  			$messaggio = "Error"; $tr = 1; break;
case "Transazione inesistente o scaduta":	$messaggio = "Nonexistent or expired transaction"; $tr = 1; break;
case "Codice di verifica errato":	$messaggio = "Wrong verification code"; $tr = 1; break;
case "Email pagante":  			$messaggio = "Payer email"; $tr = 1; break;
case "Transazione non completata, controllare la posta per conoscere lo stato della prenotazione":	$messaggio = "Transaction not ended, check your email to verify the reservation status"; $tr = 1; break;
case "Grazie per la sua prenotazione":	$messaggio = "Thank you for booking with us"; $tr = 1; break;
case "Dettagli della prenotazione":	$messaggio = "Reservation details"; $tr = 1; break;
case "Pagato":  			$messaggio = "Paid"; $tr = 1; break;
case "NOTA":  				$messaggio = "NOTE"; $tr = 1; break;
case "A causa della variazione di disponibilità durante il completamento della prenotazione":	$messaggio = "Because of an availability change during reservation completion"; $tr = 1; break;
case "il prezzo originario di":  	$messaggio = "the original price of"; $tr = 1; break;
case "è stato variato":  		$messaggio = "has been changed"; $tr = 1; break;
case "Contattare":  			$messaggio = "Contact"; $tr = 1; break;
case "se si desidera chiedere la cancellazione della prenotazione e un rimborso della caparra pagata":	$messaggio = "if you want to ask the cancellation of the reservation and a refund of the deposit paid"; $tr = 1; break;
case "Conferma prenotazione":  		$messaggio = "Reservation confirmed"; $tr = 1; break;
case "non è stato possibile inserire la prenotazione":	$messaggio = "it was not possible to insert the reservation"; $tr = 1; break;
case "per un rimborso della caparra pagata":	$messaggio = "for a refund of the deposit paid"; $tr = 1; break;
case "Prenotazione fallita":  		$messaggio = "Reservation failed"; $tr = 1; break;
case "Prenotazione inserita con successo":	$messaggio = "Reservation succesfully inserted"; $tr = 1; break;
case "E' stata inviata una email di conferma della prenotazione":	$messaggio = "An email confirming the reservation has been sent"; $tr = 1; break;
case "La prenotazione è stata inserita ma":	$messaggio = "The reservation has been inserted but"; $tr = 1; break;
case "il prezzo totale è variato a":	$messaggio = "total price has changed to"; $tr = 1; break;
case "Inserire in questa variabile l'url della pagina se \$PHP_SELF o \$SERVER_NAME non sono definiti":	$messaggio = "Insert in this variable the page url if \$PHP_SELF or \$SERVER_NAME are not defined"; $tr = 1; break;
case "Indirizzo email del proprio account <b style=\"font-weight: normal; text-decoration: underline;\">primario</b> di PayPal":	$messaggio = "Email address of your own <b style=\"font-weight: normal; text-decoration: underline;\">primary</b> PayPal account"; $tr = 1; break;
case "si consiglia vivamente di disattivare la possibilità di ricevere pagamenti via eCheck":	$messaggio = "it is strongly recommended to block the possibility to receive payments by eCheck"; $tr = 1; break;
case "su questo account per evitare che la prenotazione non possa essere conclusa a causa di":	$messaggio = "on this account to avoid the reservation not being completed because of"; $tr = 1; break;
case "variazioni di disponibilità durante l'attesa del pagamento":	$messaggio = "changes in availability when waiting for the payment"; $tr = 1; break;
case "Valuta in cui si desidera ricevere i pagamenti PayPal":	$messaggio = "Currency for PayPal payments"; $tr = 1; break;
case "Indirizzo email a cui mandare le comunicazioni":	$messaggio = "Email address where communications must be sent"; $tr = 1; break;
case "Pagina per prenotazioni con PayPal":	$messaggio = "Page to book with PayPal"; $tr = 1; break;
case "Crea la pagina per le prenotazioni con PayPal":	$messaggio = "Create the PayPal booking page"; $tr = 1; break;
case "Prenota con PayPal":  		$messaggio = "Book with PayPal"; $tr = 1; break;
case "Inviare anche comunicazioni delle mail col codice di verifica?":	$messaggio = "Send also communications of mails with verification code?"; $tr = 1; break;
case "-->":  				$messaggio = "-->"; $tr = 1; break;
case "Controllo Disponibilità":  	$messaggio = "Availability Check"; $tr = 1; break;
case "Inserimento Dati":  		$messaggio = "Data Insertion"; $tr = 1; break;
case "Verifica Email":  		$messaggio = "Email Validation"; $tr = 1; break;
case "Pagamento Caparra":  		$messaggio = "Deposit Payment"; $tr = 1; break;
case "Pagina prenotazione immediata":	$messaggio = "Instant booking page"; $tr = 1; break;
case "Testo dell'email di conferma prenotazione":	$messaggio = "Text of the email that confirms reservation"; $tr = 1; break;
case "documento":  			$messaggio = "documento"; $tr = 1; break;
case "email predefinita":  		$messaggio = "default email"; $tr = 1; break;
case "Dati della carta di credito":	$messaggio = "Credit card data"; $tr = 1; break;
case "Titolare della carta":  		$messaggio = "Card holder"; $tr = 1; break;
case "Tipo di carta":  			$messaggio = "Card type"; $tr = 1; break;
case "Numero della carta":  		$messaggio = "Card number"; $tr = 1; break;
case "Data di scadenza":  		$messaggio = "Expiration date"; $tr = 1; break;
case "Numero CCV2":  			$messaggio = "CCV2 number"; $tr = 1; break;
case "Cosa è il codice di sicurezza CCV2?":	$messaggio = "What is the CCV2 security code?"; $tr = 1; break;
case "Sono le ultime 3 cifre che seguono il numero della carta nel campo della firma, sul retro della carta":	$messaggio = "It is the last 3 digits that follow the card number in the signature area, on the back of the card"; $tr = 1; break;
case "Sono le 4 cifre sopra il numero sul fronte della carta, sul lato destro o sinistro":	$messaggio = "It is the 4 digits above the number on the front of the card, on either right or left side"; $tr = 1; break;
case "cos'è?":  			$messaggio = "what's this?"; $tr = 1; break;
case "Tipo di carta non valido":	$messaggio = "Invalid card type"; $tr = 1; break;
case "Numero di carta non valido":	$messaggio = "Invalid card number"; $tr = 1; break;
case "Data di scadenza non valida":	$messaggio = "Invalid expiration date"; $tr = 1; break;
case "Numero CCV2 non valido":		$messaggio = "Invalid CCV2 number"; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;

case "mdl_prenotazione_immediata.php":	$messaggio = "fr_instant_booking_tpl.php"; $tr = 1; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-fr_3.0.8-1.tar.gz: fr/modt_pay.php <==
<?php

switch ($messaggio) {

case "Procedere con la prenotazione":	$messaggio = "Proceed booking"; $tr = 1; break;
case "altro":  				$messaggio = "other"; $tr = 1; break;
case "Indirizzo":  			$messaggio = "Address"; $tr = 1; break;
case "Prenota":  			$messaggio = "Book"; $tr = 1; break;
case "comportati come se non vi fosse più disponibilità con questa frase alternativa":	$messaggio = "Show that there is no more availability with this alternative phrase"; $tr = 1; break;
case "Nota: questi dati verranno utilizzati solo in relazione<br> al servizio offerto e comunicati solo a PayPal per il<br> completamento della prenotazione":	$messaggio = "Note: this data will be used only in relation to<br> this service and passed only to PayPal for the<br> completion of the reservation"; $tr = 1; break;
case "Un codice di verifica è stato inviato a":	$messaggio = "A verification code has been sent to"; $tr = 1; break;
case "Controlla la posta e inserisci il codice in questa pagina per effettuare la prenotazione":	$messaggio = "Check your mail and insert the code in this page to make the reservation"; $tr = 1; break;
case "Codice di verifica":  		$messaggio = "Verification code"; $tr = 1; break;
case "Annulla":  			$messaggio = "Cancel"; $tr = 1; break;
case "Per procedere con la prenotazione inserisci il codice o segui questo link":	$messaggio = "To proceed with reservation insert the code or follow this link"; $tr = 1; break;
case "Codice verifica prenotazione":	$messaggio = "Reservation verification code"; $tr = 1; break;
case "Numero eccesivo di richieste inviate dallo stesso computer":	$messaggio = "Excessive number of requests sent from the same computer"; $tr = 1; break;
case "Completa la prenotazione pagando la caparra con PayPal":	$messaggio = "To complete the reservation you have to pay the deposit with PayPal"; $tr = 1; break;
case "Dopo il pagamento della caparra potrai considerare la prenotazione come confermata solo dopo aver ricevuto il codice prenotazione":	$messaggio = "After the payment of the deposit you can consider the reservation as confirmed only after receiving the reservation code"; $tr = 1; break;
case "Paga la caparra con PayPal":  	$messaggio = "Pay the deposit with PayPal"; $tr = 1; break;
case "Nota: i dati della carta di credito verranno elaborati dai<br> server sicuri di PayPal ed in nessun caso comunicati a questo sito":	$messaggio = "Note: credit card data will be processed by PayPal<br> secure servers and never revealed to this site"; $tr = 1; break;
case "Prenotazione":  			$messaggio = "Reservation"; $tr = 1; break;
case "Errore transazione PayPal":  	$messaggio = "PayPal transaction error"; $tr = 1; break;
case "Errore":  			$messaggio = "Error"; $tr = 1; break;
case "Transazione inesistente o scaduta":	$messaggio = "Nonexistent or expired transaction"; $tr = 1; break;
case "Codice di verifica errato":	$messaggio = "Wrong verification code"; $tr = 1; break;
case "Email pagante":  			$messaggio = "Payer email"; $tr = 1; break;
case "Transazione non completata, controllare la posta per conoscere lo stato della prenotazione":	$messaggio = "Transaction not ended, check your email to verify the reservation status"; $tr = 1; break;
case "Grazie per la sua prenotazione":	$messaggio = "Thank you for booking with us"; $tr = 1; break;
case "Dettagli della prenotazione":	$messaggio = "Reservation details"; $tr = 1; break;
case "Pagato":  			$messaggio = "Paid"; $tr = 1; break;
case "NOTA":  				$messaggio = "NOTE"; $tr = 1; break;
case "A causa della variazione di disponibilità durante il completamento della prenotazione":	$messaggio = "Because of an availability change during reservation completion"; $tr = 1; break;
case "il prezzo originario di":  	$messaggio = "the original price of"; $tr = 1; break;
case "è stato variato":  		$messaggio = "has been changed"; $tr = 1; break;
case "Contattare":  			$messaggio = "Contact"; $tr = 1; break;
case "se si desidera chiedere la cancellazione della prenotazione e un rimborso della caparra pagata":	$messaggio = "if you want to ask the cancellation of the reservation and a refund of the deposit paid"; $tr = 1; break;
case "Conferma prenotazione":  		$messaggio = "Reservation confirmed"; $tr = 1; break;
case "non è stato possibile inserire la prenotazione":	$messaggio = "it was not possible to insert the reservation"; $tr = 1; break;
case "per un rimborso della caparra pagata":	$messaggio = "for a refund of the deposit paid"; $tr = 1; break;
case "Prenotazione fallita":  		$messaggio = "Reservation failed"; $tr = 1; break;
case "Prenotazione inserita con successo":	$messaggio = "Reservation succesfully inserted"; $tr = 1; break;
case "E' stata inviata una email di conferma della prenotazione":	$messaggio = "An email confirming the reservation has been sent"; $tr = 1; break;
case "La prenotazione è stata inserita ma":	$messaggio = "The reservation has been inserted but"; $tr = 1; break;
case "il prezzo totale è variato a":	$messaggio = "total price has changed to"; $tr = 1; break;
case "Inserire in questa variabile l'url della pagina se \$PHP_SELF o \$SERVER_NAME non sono definiti":	$messaggio = "Insert in this variable the page url if \$PHP_SELF or \$SERVER_NAME are not defined"; $tr = 1; break;
case "Indirizzo email del proprio account <b style=\"font-weight: normal; text-decoration: underline;\">primario</b> di PayPal":	$messaggio = "Email address of your own <b style=\"font-weight: normal; text-decoration: underline;\">primary</b> PayPal account"; $tr = 1; break;
case "si consiglia vivamente di disattivare la possibilità di ricevere pagamenti via eCheck":	$messaggio = "it is strongly recommended to block the possibility to receive payments by eCheck"; $tr = 1; break;
case "su questo account per evitare che la prenotazione non possa essere conclusa a causa di":	$messaggio = "on this account to avoid the reservation not being completed because of"; $tr = 1; break;
case "variazioni di disponibilità durante l'attesa del pagamento":	$messaggio = "changes in availability when waiting for the payment"; $tr = 1; break;
case "Valuta in cui si desidera ricevere i pagamenti PayPal":	$messaggio = "Currency for PayPal payments"; $tr = 1; break;
case "Indirizzo email a cui mandare le comunicazioni":	$messaggio = "Email address where communications must be sent"; $tr = 1; break;
case "Pagina per prenotazioni con PayPal":	$messaggio = "Page to book with PayPal"; $tr = 1; break;
case "Crea la pagina per le prenotazioni con PayPal":	$messaggio = "Create the PayPal booking page"; $tr = 1; break;
case "Prenota con PayPal":  		$messaggio = "Book with PayPal"; $tr = 1; break;
case "Inviare anche comunicazioni delle mail col codice di verifica?":	$messaggio = "Send also communications of mails with verification code?"; $tr = 1; break;
case "-->":  				$messaggio = "-->"; $tr = 1; break;
case "Controllo Disponibilità":  	$messaggio = "Availability Check"; $tr = 1; break;
case "Inserimento Dati":  		$messaggio = "Data Insertion"; $tr = 1; break;
case "Verifica Email":  		$messaggio = "Email Validation"; $tr = 1; break;
case "Pagamento Caparra":  		$messaggio = "Deposit Payment"; $tr = 1; break;
case "Pagina prenotazione immediata":	$messaggio = "Instant booking page"; $tr = 1; break;
case "Testo dell'email di conferma prenotazione":	$messaggio = "Text of the email that confirms reservation"; $tr = 1; break;
case "documento":  			$messaggio = "documento"; $tr = 1; break;
case "email predefinita":  		$messaggio = "default email"; $tr = 1; break;
case "Dati della carta di credito":	$messaggio = "Credit card data"; $tr = 1; break;
case "Titolare della carta":  		$messaggio = "Card holder"; $tr = 1; break;
case "Tipo di carta":  			$messaggio = "Card type"; $tr = 1; break;
case "Numero della carta":  		$messaggio = "Card number"; $tr = 1; break;
case "Data di scadenza":  		$messaggio = "Expiration date"; $tr = 1; break;
case "Numero CCV2":  			$messaggio = "CCV2 number"; $tr = 1; break;
case "Cosa è il codice di sicurezza CCV2?":	$messaggio = "What is the CCV2 security code?"; $tr = 1; break;
case "Sono le ultime 3 cifre che seguono il numero della carta nel campo della firma, sul retro della carta":	$messaggio = "It is the last 3 digits that follow the card number in the signature area, on the back of the card"; $tr = 1; break;
case "Sono le 4 cifre sopra il numero sul fronte della carta, sul lato destro o sinistro":	$messaggio = "It is the 4 digits above the number on the front of the card, on either right or left side"; $tr = 1; break;
case "cos'è?":  			$messaggio = "what's this?"; $tr = 1; break;
case "Tipo di carta non valido":	$messaggio = "Invalid card type"; $tr = 1; break;
case "Numero di carta non valido":	$messaggio = "Invalid card number"; $tr = 1; break;
case "Data di scadenza non valida":	$messaggio = "Invalid expiration date"; $tr = 1; break;
case "Numero CCV2 non valido":		$messaggio = "Invalid CCV2 number"; $tr = 1; break;
case "Dati carta":  			$messaggio = "Card data"; $tr = 1; break;
case "Tipi di carte di credito accettate":	$messaggio = "Accepted credit card types"; $tr = 1; break;
case "questo servizio di pagamento viene attivato solo se è stata impostata una password per le carte":	$messaggio = "this payment service is activated only if a password for credit cards has been"; $tr = 1; break;
case "di credito e ci si collega con connessione sicura ssl (https), è comunque rischioso utilizzarlo in quanto la":	$messaggio = "set and there is a secure ssl connection (https), anyway using this service is a risk as"; $tr = 1; break;
case "validità della carta di credito non viene verificata":	$messaggio = "the credit card validity is not checked"; $tr = 1; break;
case "Per utilizzare questo servizio di pagamento si deve inviare il codice per la verifica dell'indirizzo email":	$messaggio = "This payment service requires sending the code to verify the email address"; $tr = 1; break;
case "mostrare foto e descrizioni delle tariffe nella lista delle tipologie?":	$messaggio = "show photos and descriptions of rates in types list?"; $tr = 1; break;
case "foto":  				$messaggio = "photo"; $tr = 1; break;
case "precedente":  			$messaggio = "previous"; $tr = 1; break;
case "successiva":  			$messaggio = "next"; $tr = 1; break;
case "mostrare tipologie che hanno nella regola di assegnazione 4 un numero di persone diverso?":	$messaggio = "show types that have in assignment rule 4 a different number of people?"; $tr = 1; break;
case "Geometria della finestra delle fotografie":	$messaggio = "Photos window geometry"; $tr = 1; break;
case "la form per il pagamento non sarà disponibile fino a quando la password per vedere le carte di credito non verrà attivata in \"configura e personalizza\"":	$messaggio = "payment form won't be available until credit card password is not activated in \"configure and customize\""; $tr = 1; break;
case "la form per il pagamento non sarà disponibile se non verrà utilizzata una connessione sicura ssl (URL che inizia con https://)":	$messaggio = "payment form won't be available if not used on a secure ssl connection (URL that begins with https://)"; $tr = 1; break;
case "ci sono tariffe senza caparra, per esse non verrà mostrata la form di prenotazione":	$messaggio = "there are rates without deposit, payment form won't be shown for them"; $tr = 1; break;
case "inserire foto e descizioni cliccando sulla tariffa dalla":	$messaggio = "Insert photos and descriptions clicking on the rate from the"; $tr = 1; break;
case "tabella con i periodi e le tariffe":	$messaggio = "table with periods and rates"; $tr = 1; break;
case "Mostrare all'ultimo passo i dettagli della prenotazione con la pagina per confermare se presente?":	$messaggio = "Show as last step the reservation details with the confirmation page if present?"; $tr = 1; break;
case "Nome file della pagina per confermare la prenotazione":	$messaggio = "Confirm reservation page filename"; $tr = 1; break;
case "Richiedi prenotazione":  		$messaggio = "Reservation request"; $tr = 1; break;
case "Sicurezza con O.T.P.":  		$messaggio = "Security with O.T.P."; $tr = 1; break;
case "Sicurezza con crittografia":  	$messaggio = "Security with cryptography"; $tr = 1; break;
case "di MercadoPago":  				$messaggio = "for MercadoPago"; $tr = 1; break;
case "Valuta in cui si desidera ricevere i pagamenti MercadoPago":	$messaggio = "Currency for MercadoPago payments"; $tr = 1; break;
case "Percorso completo alla libreria":	$messaggio = "Absolute path to library"; $tr = 1; break;
case "nella stessa directory si deve trovare anche il certificato \"cacert.pem\"":	$messaggio = "the \"cacert.pem\" certificate must be placed in the same directory"; $tr = 1; break;
case "le <b>notifiche immediate di pagamento</b> (IPN) devono essere attivate nel vostro":	$messaggio = "the <b>Instant payment notifications</b> (IPN) must be enabled in your PayPal"; $tr = 1; break;
case "account di PayPal, nella sezione \"<em>Preferenze venditore</em>\"":	$messaggio = "account, under section \"<em>Seller preferences</em>\""; $tr = 1; break;
case "Inoltre la pagina creata deve":  	$messaggio = "Furthermore the created page must"; $tr = 1; break;
case "essere raggiungibile con connessione sicura (<em>https</em>)":	$messaggio = "be reachable with a secure connection (<em>https</em>)"; $tr = 1; break;
case "In attesa della conferma del pagamento":	$messaggio = "Waiting for payment confirmation"; $tr = 1; break;
case "Siamo in attesa della conferma del pagamento, dovreste ricevere una email di conferma a breve":	$messaggio = "We are waiting for payment confirmation, you should receive a confirmation emeil shortly"; $tr = 1; break;
case "Applica":  			$messaggio = "Apply"; $tr = 1; break;
case "a partire da":  			$messaggio = "starting from"; $tr = 1; break;
case "Valuta corrispondente a":  	$messaggio = "Currency corresponding to"; $tr = 1; break;
case "Possibilità di scegliere altre valute?":	$messaggio = "Possibility to choose other currencies?"; $tr = 1; break;
case "Recupera le crelenziali di accesso da":	$messaggio = "Get the access credentials from"; $tr = 1; break;
case "QUI":  				$messaggio = "HERE"; $tr = 1; break;
case "Codice prenotazione":  		$messaggio = "Reservation code"; $tr = 1; break;
case "Non disponibile":  		$messaggio = "Not available"; $tr = 1; break;
case "Incompatibile con":  		$messaggio = "Incompatible with"; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;

case "mdl_prenotazione_immediata.php":	$messaggio = "fr_instant_booking_tpl.php"; $tr = 1; break;

} # fine switch ($messaggio)

?>
